@@ -39,13 +39,7 @@ my $make = $Config{make};
 my $temp_stdout = File::Temp->new()
     or die "Couldn't make temporary file:$!\nIs your temp drive full?";
 
-my $temp_dist_dir = tempdir( 'CR-t-dist-XXXXXX', CLEANUP => 1, TMPDIR => 1);
-my $dist_archive = File::Spec->rel2abs("t/dist.tgz");
-{
-  my $wd = pushd($temp_dist_dir);
-  Archive::Tar->extract_archive($dist_archive, 1)
-    or die "Could not extract test distributions: " . Archive::Tar->error;
-}
+my $corpus_dir = "./corpus";
 
 my $home_dir = t::MockHomeDir::home_dir();
 my $config_dir = File::Spec->catdir( $home_dir, ".cpanreporter" );
@@ -679,7 +673,9 @@ sub _diag_output {
 sub _ok_clone_dist_dir {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     my $dist_name = shift;
-    my $dist_dir = File::Spec->catdir( $temp_dist_dir, "dist", $dist_name );
+    my $dist_dir = File::Spec->rel2abs(
+        File::Spec->catdir( $corpus_dir, $dist_name )
+    );
     my $work_dir = tempd()
         or die "Couldn't create temporary distribution dir: $!\n";
 
